import java.io.*;
import java.util.*;

public class elevator_ai {
	static final int MAXN = 100000;
	static final int MAXM = 100000;
	static final int MAXA = 100;
	static final int MAXB = 100;
	static final int MAXT = 1000000000;
	
	static final long INF = 1000000000000000000l;
	
	class IntervalTree {
		int[] a;
		long[] b;
		int n;
		
		IntervalTree(int n) {
			int t = 1;
			while (t < n) t <<= 1;
			this.n = t;
			a = new int[(this.n << 1) - 1];
			b = new long[this.n];
			for (int i = 0; i < this.n; ++i) b[i] = INF;
			for (int i = 0; i < this.n; ++i) a[this.n - 1 + i] = i;
			for (int i = this.n - 2; i >= 0; --i)
				a[i] = a[(i << 1) + 1];
		}
	
		long getMinimum(int l, int r) {
			long result = b[l];
			l += n - 1; r += n - 1;
			while (l <= r) {
				if ((l & 1) == 0) {
					result = Math.min(result, b[a[l]]);
					++l;
				}
				if ((r & 1) != 0) {
					result = Math.min(result, b[a[r]]);
					--r;
				}
				l = (l - 1) >> 1; r = (r - 1) >> 1;
			}
			return result;
		}
		
		void update(int i, long v) {
			b[i] = v;
			i += n - 1;
			while (i > 0) {
				int p = (i - 1) >> 1;
				if (b[a[(p << 1) + 1]] <= b[a[(p << 1) + 2]]) a[p] = a[(p << 1) + 1];
				else a[p] = a[(p << 1) + 2];
				i = p;
			}
		}
	}

	class Query {
		int time, floor, next;
		long served, value1, value2;
		Query(int time, int floor) {
			this.time = time; this.floor = floor;
			this.served = -1;
			this.next = -1;
		}
	}
	
	void run() throws Exception {
		long timeStarted = new Date().getTime();
		
		BufferedReader in = new BufferedReader(new FileReader("elevator.in"));
		StringTokenizer st = new StringTokenizer(in.readLine());
		int n = Integer.parseInt(st.nextToken());
		int m = Integer.parseInt(st.nextToken());
		int a = Integer.parseInt(st.nextToken());
		int b = Integer.parseInt(st.nextToken());
		assert (1 <= n) && (n <= MAXN) : "Wrong N value";
		assert (1 <= m) && (m <= MAXM) : "Wrong M value";
		assert (1 <= a) && (a <= MAXA) : "Wrong A value";
		assert (1 <= b) && (b <= MAXB) : "Wrong B value";
		Query[] q = new Query[m];
		int[] first = new int[n];
		int[] last = new int[n];
		Arrays.fill(first, -1);
		Arrays.fill(last, -1);
		IntervalTree tree1 = new IntervalTree(n);
		IntervalTree tree2 = new IntervalTree(n);
		for (int i = 0; i < m; ++i) {
			st = new StringTokenizer(in.readLine());
			q[i] = new Query(Integer.parseInt(st.nextToken()), Integer.parseInt(st.nextToken()) - 1);
			assert (1 <= q[i].time) && (q[i].time <= MAXT) : "Wrong query " + i + " time value";
			assert (0 <= q[i].floor) && (q[i].floor <= n - 1) : "Wrong query " + i + " floor value";
			q[i].value1 = (long)q[i].time - (long)b * (long)q[i].floor;
			q[i].value2 = (long)q[i].time + (long)b * (long)q[i].floor;
			if (last[q[i].floor] == -1) {
				first[q[i].floor] = last[q[i].floor] = i;
				tree1.update(q[i].floor, q[i].value1);
				tree2.update(q[i].floor, q[i].value2);
			} else {
				q[last[q[i].floor]].next = i;
				last[q[i].floor] = i;
			}
		}
		in.close();
		
		long timeStayed = 0, time = 0;
		int floor = 0;
		for (int i = 0; i < m; ++i) if (q[i].served == -1) {
			assert first[q[i].floor] == i : "Floor " + q[i].floor + " queries list doesn't begin with current query " + i;
			assert INF - Math.max(0, q[i].time - time) >= timeStayed : "Long overflow";
			timeStayed += Math.max(0, q[i].time - time);
			time = Math.max(time, q[i].time);
			int direction = (q[i].floor > floor ? 1 : (q[i].floor < floor ? -1 : 0));
			do {
				if (direction > 0) {
					long value3 = time - (long)b * (long)floor;
					int l = floor - 1, r = q[i].floor;
					while (r - l > 1) {
						int x = (l + r) >> 1;
						if (tree1.getMinimum(floor, x) > value3) l = x;
						else r = x;
					}
					time += (long)b * (long)(r - floor);
					floor = r;
				} else if (direction < 0) {
					assert INF - time >= (long)b * (long)floor : "Long overflow";
					long value3 = time + (long)b * (long)floor;
					int l = floor + 1, r = q[i].floor;
					while (l - r > 1) {
						int x = (l + r) >> 1;
						if (tree2.getMinimum(x, floor) > value3) l = x;
						else r = x;
					}
					time += (long)b * (long)(floor - r);
					floor = r;
				}
				while ((first[floor] != -1) && (q[first[floor]].time <= time)) {
					q[first[floor]].served = time;
					assert INF - a >= time : "Long overflow";
					time += a;
					first[floor] = q[first[floor]].next;
					tree1.update(floor, first[floor] != -1 ? q[first[floor]].value1 : INF);
					tree2.update(floor, first[floor] != -1 ? q[first[floor]].value2 : INF);
				}
			} while (floor != q[i].floor);
		}
		long timeMoved = time - timeStayed - (long)m * (long)a;

		PrintWriter out = new PrintWriter(new FileWriter("elevator.out"));
//		out.println("Elevator was remaining motionless during " + timeStayed + " seconds");
//		out.println("and was moving during " + timeMoved + " seconds.");
		for (int i = 0; i < m; ++i) {
			out.println(q[i].served);
		}
		out.close();

		System.out.println("Fast solution finished in " + (new Date().getTime() - timeStarted)+ "ms");
	}
	
	public static void main(String[] args) throws Exception {
		new elevator_ai().run();
	}
}
