#include <stdio.h>
#include <math.h>
#include <string.h>
#include <memory.h>
#include <stdlib.h>
#include <ctype.h>
#include <vector>
#include <string>
#include <map>
#include <set>
#include <algorithm>
#include <iostream>
using namespace std;
typedef long long LL;
typedef pair<int, int> pii;
typedef vector<int> vint;
typedef vector<string> vstr;
#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=a;i--)
#define ALL(v) v.begin(),v.end()
const int INF = 0x7FFFFFFF;
const double PI = 3.1415926535897932384626433832795;

const double EPS = 1e-8;

inline double sqr(double x) {
  return x * x;
}

struct Vector {
  double x, y, z;
  Vector() {}
  Vector(double x, double y, double z) : x(x), y(y), z(z) {}

  double length2() {
    return x * x + y * y + z * z;
  }
  double length() {
    return sqrt(x * x + y * y + z * z);
  }
  Vector& normalize() {
    double len = sqrt(x * x + y * y + z * z);
    x /= len; y /= len; z /= len;
    return *this;
  }

  Vector& operator += (Vector const& v) {
    x += v.x; y += v.y; z += v.z;
    return *this;
  }
  Vector& operator -= (Vector const& v) {
    x -= v.x; y -= v.y; z -= v.z;
    return *this;
  }
  Vector& operator *= (double f) {
    x *= f; y *= f; z *= f;
    return *this;
  }
  Vector& operator /= (double f) {
    x /= f; y /= f; z /= f;
    return *this;
  }
};
Vector operator + (Vector const& a, Vector const& b) {
  return Vector(a.x + b.x, a.y + b.y, a.z + b.z);
}
Vector operator - (Vector const& a, Vector const& b) {
  return Vector(a.x - b.x, a.y - b.y, a.z - b.z);
}
Vector operator - (Vector const& a) {
  return Vector(-a.x, -a.y, -a.z);
}
Vector operator * (Vector const& a, Vector const& b) {
  return Vector(a.x * b.x, a.y * b.y, a.z * b.z);
}
Vector operator * (Vector const& a, double f) {
  return Vector(a.x * f, a.y * f, a.z * f);
}
Vector operator * (double f, Vector const& a) {
  return Vector(a.x * f, a.y * f, a.z * f);
}
Vector operator / (Vector const& a, double f) {
  return Vector(a.x / f, a.y / f, a.z / f);
}
double dot(Vector const& a, Vector const& b) {
  return a.x * b.x + a.y * b.y + a.z * b.z;
}
Vector cross(Vector const& a, Vector const& b) {
  return Vector(a.y * b.z - a.z * b.y,
                a.z * b.x - a.x * b.z,
                a.x * b.y - a.y * b.x);
}

bool operator < (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x < b.x;
  if (fabs(a.y - b.y) >= EPS) return a.y < b.y;
  return a.z < b.z - EPS;
}
bool operator <= (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x < b.x;
  if (fabs(a.y - b.y) >= EPS) return a.y < b.y;
  return a.z <= b.z + EPS;
}
bool operator > (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x > b.x;
  if (fabs(a.y - b.y) >= EPS) return a.y > b.y;
  return a.z > b.z + EPS;
}
bool operator >= (Vector const& a, Vector const& b) {
  if (fabs(a.x - b.x) >= EPS) return a.x > b.x;
  if (fabs(a.y - b.y) >= EPS) return a.y > b.y;
  return a.z >= b.z - EPS;
}
bool operator == (Vector const& a, Vector const& b) {
  return fabs(a.x - b.x) < EPS && fabs(a.y - b.y) < EPS && fabs(a.z - b.z) < EPS;
}
bool operator != (Vector const& a, Vector const& b) {
  return fabs(a.x - b.x) >= EPS || fabs(a.y - b.y) >= EPS || fabs(a.z - b.z) >= EPS;
}

typedef Vector Point;

struct Plane {
  Vector n;
  double d;

  Plane() {}
  Plane(Vector n, double d) : n(n), d(d) {}
  Plane(Point const& a, Point const& b, Point const& c) {
    n = cross(b - a, c - a);
    n.normalize();
    d = -dot(a, n);
  }

  void flip() {
    n = -n;
    d = -d;
  }

  double f(Point const& x) const {
    return dot(x, n) + d;
  }
};

struct Polygon {
  vector<Point> points;
  Plane plane;
  void build() {
    plane = Plane(points[0], points[1], points[2]);
  }
  void clip(Plane const& p) {
    vector<Point> npoints;
    for (int i = 0; i < points.size(); i++) {
      int j = i - 1; if (j < 0) j += points.size();
      double fi = p.f(points[i]);
      double fj = p.f(points[j]);
      if (fi * fj < -EPS) {
        npoints.push_back(points[j] + (points[i] - points[j]) * ((0 - fj) / (fi - fj)));
      }
      if (fi > -EPS) {
        npoints.push_back(points[i]);
      }
    }
    points = npoints;
  }
  double area() {
    double result = 0;
    for (int i = 2; i < points.size(); i++) {
      result += cross(points[i] - points[0], points[i - 1] - points[0]).length() * 0.5;
    }
    return result;
  }
  void flip() {
    reverse(points.begin(), points.end());
    plane.flip();
  }

  Point middle() {
    Point sum(0, 0, 0);
    for (int i = 0; i < points.size(); i++) {
      sum += points[i];
    }
    return sum / points.size();
  }
};

struct Cube {
  Vector pt[8];
  Polygon sides[6];
  void read() {
    cin >> pt[0].x >> pt[0].y >> pt[0].z;
    cin >> pt[1].x >> pt[1].y >> pt[1].z;
    cin >> pt[2].x >> pt[2].y >> pt[2].z;
    cin >> pt[4].x >> pt[4].y >> pt[4].z;
    pt[3] = pt[1] + pt[2] - pt[0];
    pt[5] = pt[4] + pt[1] - pt[0];
    pt[6] = pt[4] + pt[2] - pt[0];
    pt[7] = pt[5] + pt[2] - pt[0];

    sides[0].points.push_back(pt[0]);
    sides[0].points.push_back(pt[1]);
    sides[0].points.push_back(pt[3]);
    sides[0].points.push_back(pt[2]);
    sides[0].build();
    if (sides[0].plane.f(pt[4]) > 0) {
      sides[0].flip();
    }

    sides[1].points.push_back(pt[4]);
    sides[1].points.push_back(pt[6]);
    sides[1].points.push_back(pt[7]);
    sides[1].points.push_back(pt[5]);
    sides[1].build();
    if (sides[1].plane.f(pt[0]) > 0) {
      sides[1].flip();
    }

    sides[2].points.push_back(pt[0]);
    sides[2].points.push_back(pt[4]);
    sides[2].points.push_back(pt[5]);
    sides[2].points.push_back(pt[1]);
    sides[2].build();
    if (sides[2].plane.f(pt[2]) > 0) {
      sides[2].flip();
    }

    sides[3].points.push_back(pt[2]);
    sides[3].points.push_back(pt[3]);
    sides[3].points.push_back(pt[7]);
    sides[3].points.push_back(pt[6]);
    sides[3].build();
    if (sides[3].plane.f(pt[0]) > 0) {
      sides[3].flip();
    }

    sides[4].points.push_back(pt[0]);
    sides[4].points.push_back(pt[2]);
    sides[4].points.push_back(pt[6]);
    sides[4].points.push_back(pt[4]);
    sides[4].build();
    if (sides[4].plane.f(pt[1]) > 0) {
      sides[4].flip();
    }

    sides[5].points.push_back(pt[1]);
    sides[5].points.push_back(pt[5]);
    sides[5].points.push_back(pt[7]);
    sides[5].points.push_back(pt[3]);
    sides[5].build();
    if (sides[5].plane.f(pt[0]) > 0) {
      sides[5].flip();
    }
  }
};

struct Frustum {
  vector<Plane> planes;
  Frustum(Point const& p, Polygon const& poly) {
    for (int i = 0; i < poly.points.size(); i++) {
      Plane plane(p, poly.points[i], poly.points[(i + 1) % poly.points.size()]);
      if (plane.f(poly.points[(i + 2) % poly.points.size()]) < 0) {
        plane.flip();
      }
      planes.push_back(plane);
    }
  }

  Polygon clip(Polygon const& poly) {
    Polygon result(poly);
    for (int i = 0; i < planes.size(); i++) {
      result.clip(planes[i]);
    }
    return result;
  }
};

double shadow(Point const& p, Cube const& a, Cube const& b) {
  double result = 0;
  for (int i = 0; i < 6; i++) for (int j = 0; j < 6; j++) {
    if (a.sides[i].plane.f(p) < EPS || b.sides[j].plane.f(p) < EPS) continue;
    Frustum frustum(p, a.sides[i]);
    Polygon clipped = frustum.clip(b.sides[j]);
    if (clipped.points.size() == 0) continue;
    Point middle = clipped.middle();
    if (a.sides[i].plane.f(middle) > -EPS) continue;
    result += clipped.area();
  }
  return result;
}

int main() {
  Point c;
  cin >> c.x >> c.y >> c.z;
  Cube a, b;
  a.read();
  b.read();
  cout.precision(9);
  double area = shadow(c, a, b);
  if (area > EPS) {
    cout << "2 " << fixed << area;
  } else {
    area = shadow(c, b, a);
    if (area > EPS) {
      cout << "1 " << fixed << area;
    } else {
      cout << "-1";
    }
  }
  return 0;
}
