#include <algorithm>
#include <stack>
#include <cassert>
#include <cmath>
#include <complex>
#include <cstdio>
#include <cstring>
#include <iostream>
#include <map>
#include <set>
#include <string>
#include <sstream>
#include <vector>
using namespace std;

typedef pair<int, int> ii;
typedef vector<int> vi;
typedef vector<ii> vii;
typedef vector<vector<int> > vvi;
typedef long long ll;
template <class T> int size(const T& x) {return x.size();}

const double EPS = 1e-9;
const int INF = 2147483647;

const ii ID(0, 0);
ii f(ii a, ii b) {
    return ii(a.first + b.first, a.second + b.second);
}

struct segment_tree {
    int n;
    vii data;
    segment_tree() {
    }

    segment_tree(const vii &arr) : n(size(arr)), data(4*n) {
        mk(arr, 0, n-1, 0);
    }

    ii mk(const vii &arr, int l, int r, int i) {
        if (l == r) return data[i] = arr[l];
        int m = (l + r) / 2;
        return data[i] = f(mk(arr, l, m, 2*i+1), mk(arr, m+1, r, 2*i+2));
    }

    ii query(int a, int b) {
        return q(a, b, 0, n-1, 0);
    }

    ii q(int a, int b, int l, int r, int i) {
        if (r < a || b < l) return ID;
        if (a <= l && r <= b) return data[i];
        int m = (l + r) / 2;
        return f(q(a, b, l, m, 2*i+1), q(a, b, m+1, r, 2*i+2));
    }

    void update(int i, ii v) {
        u(i, v, 0, n-1, 0);
    }

    ii u(int i, ii v, int l, int r, int j) {
        if (r < i || i < l) return data[j];
        if (l == i && r == i) return data[j] = v;
        int m = (l + r) / 2;
        return data[j] = f(u(i, v, l, m, 2*j+1), u(i, v, m+1, r, 2*j+2));
    }
};

struct HLD {
    int n, curhead, curloc;
    vi sz, head, parent, loc;
    vvi below; segment_tree values;
    HLD(int _n) : n(_n), sz(n, 1), head(n), parent(n, -1), loc(n), below(n) {
        vii tmp(n, ID);
        values = segment_tree(tmp);
    }
    void add_edge(int u, int v) { below[parent[v] = u].push_back(v); }
    void update_cost(int u, int v, ii c) {
        if (parent[v] == u) swap(u, v);
        assert(parent[u] == v);
        values.update(loc[u], c);
    }
    void csz(int u) {
        for (int i = 0; i < size(below[u]); i++) {
            csz(below[u][i]), sz[u] += sz[below[u][i]];
        }
    }
    void part(int u) {
        head[u] = curhead;
        loc[u] = curloc++;
        int best = -1;
        for (int i = 0; i < size(below[u]); i++) {
            if (best == -1 || sz[below[u][i]] > sz[best])
                best = below[u][i];
        }
        if (best != -1) part(best);
        for (int i = 0; i < size(below[u]); i++) {
            if (below[u][i] != best) {
                part(curhead = below[u][i]);
            }
        }
    }

    void build() {
        int u = curloc = 0;
        while (parent[u] != -1) {
            u++;
        }
        csz(u);
        part(curhead = u);
    }

    int lca(int u, int v) {
        vi uat, vat;
        int res = -1;
        while (u != -1) uat.push_back(u), u = parent[head[u]];
        while (v != -1) vat.push_back(v), v = parent[head[v]];
        u = size(uat) - 1, v = size(vat) - 1;
        while (u >= 0 && v >= 0 && head[uat[u]] == head[vat[v]]) {
            res = (loc[uat[u]] < loc[vat[v]] ? uat[u] : vat[v]),
                u--, v--;
        }
        return res;
    }

    ii query_upto(int u, int v) {
        ii res = ID;
        while (head[u] != head[v]) {
            res = f(res, values.query(loc[head[u]], loc[u]));
            u = parent[head[u]];
        }
        return f(res, values.query(loc[v] + 1, loc[u]));
    }

    ii query(int u, int v) {
        int l = lca(u, v);
        return f(query_upto(u, l), query_upto(v, l));
    }
};

struct union_find {
    vi p;
    union_find(int n) : p(n, -1) {
    }
    int find(int x) {
        return p[x] < 0 ? x : p[x] = find(p[x]);
    }
    bool unite(int x, int y) {
        int xp = find(x), yp = find(y);
        if (xp == yp) return false;
        if (p[xp] < p[yp]) p[xp] += p[yp], p[yp] = xp;
        else p[yp] += p[xp], p[xp] = yp;
        return true;
    }

    int size(int x) {
        return -p[find(x)];
    }
};


int main() {

    int n, m;
    scanf("%d %d\n", &n, &m);

    bool *used = new bool[m];
    vector<pair<ii, int> > edges(m);

    for (int i = 0; i < m; i++) {
        used[i] = false;
        int a, b, c;
        scanf("%d %d %d\n", &a, &b, &c);
        a--, b--;
        edges[i] = make_pair(ii(a, b), c);
    }

    vii *adj1 = new vii[n];

    union_find uf(n);
    for (int i = 0; uf.size(0) < n; i++) {
        int a = uf.find(edges[i].first.first),
            b = uf.find(edges[i].first.second);
        if (a != b) {
            uf.unite(a, b);
            used[i] = true;
            adj1[edges[i].first.first].push_back(make_pair(edges[i].first.second, edges[i].second));
            adj1[edges[i].first.second].push_back(make_pair(edges[i].first.first, edges[i].second));
        }
    }

    uf = union_find(n);

    bool *used2 = new bool[m];
    memset(used2, 0, m);

    vii *adj2 = new vii[n];
    for (int i = 0; i < m && uf.size(0) < n; i++) {
        if (used[i]) continue;
        int a = uf.find(edges[i].first.first),
            b = uf.find(edges[i].first.second);
        if (a != b) {
            uf.unite(a, b);
            adj2[edges[i].first.first].push_back(make_pair(edges[i].first.second, edges[i].second));
            adj2[edges[i].first.second].push_back(make_pair(edges[i].first.first, edges[i].second));
            used2[i] = true;
        }
    }

    for (int i = 0; uf.size(0) < n; i++) {
        if (!used[i]) continue;
        int a = uf.find(edges[i].first.first),
            b = uf.find(edges[i].first.second);
        if (a != b) {
            uf.unite(a, b);
            adj2[edges[i].first.first].push_back(make_pair(edges[i].first.second, edges[i].second));
            adj2[edges[i].first.second].push_back(make_pair(edges[i].first.first, edges[i].second));
            used2[i] = true;
        }
    }

    /*
    printf("Tree 1:\n");
    for (int i = 0; i < n; i++) {
        printf("%d: ", i+1);
        for (int j = 0; j < size(adj1[i]); j++) {
            printf("(%d,%d) ", adj1[i][j].first+1, adj1[i][j].second);
        }
        printf("\n");
    }

    printf("Tree 2:\n");
    for (int i = 0; i < n; i++) {
        printf("%d: ", i+1);
        for (int j = 0; j < size(adj2[i]); j++) {
            printf("(%d,%d) ", adj2[i][j].first+1, adj2[i][j].second);
        }
        printf("\n");
    }
    */

    HLD h1(n);

    bool *visited = new bool[n];
    memset(visited, 0, n);
    stack<int> S;
    S.push(0);
    visited[0] = true;
    vector<ii> es1;
    while (!S.empty()) {
        int cur = S.top(); S.pop();
        for (int i = 0; i < size(adj1[cur]); i++) {
            int nxt = adj1[cur][i].first;
            if (visited[nxt]) continue;
            h1.add_edge(cur, nxt);
            //printf("h1: %d-%d\n", cur, nxt);
            es1.push_back(ii(cur, i));
            visited[nxt] = true;
            S.push(nxt);
            //h1.update_cost(cur, nxt, len);
        }
    }
    h1.build();
    for (int i = 0; i < size(es1); i++) {
        int cur = es1[i].first;
        int nxt = adj1[es1[i].first][es1[i].second].first;
        int len = adj1[es1[i].first][es1[i].second].second;
        h1.update_cost(cur, nxt, ii(len, 1));
    }









    HLD h2(n);

    visited = new bool[n];
    memset(visited, 0, n);
    S.push(0);
    visited[0] = true;
    vector<ii> es2;
    while (!S.empty()) {
        int cur = S.top(); S.pop();
        for (int i = 0; i < size(adj2[cur]); i++) {
            int nxt = adj2[cur][i].first;
            if (visited[nxt]) continue;
            int len = adj2[cur][i].second;
            h2.add_edge(cur, nxt);
            es2.push_back(ii(cur, i));
            visited[nxt] = true;
            S.push(nxt);
            //h2.update_cost(cur, nxt, len);
        }
    }
    h2.build();
    for (int i = 0; i < size(es2); i++) {
        int cur = es2[i].first;
        int nxt = adj2[es2[i].first][es2[i].second].first;
        int len = adj2[es2[i].first][es2[i].second].second;
        h2.update_cost(cur, nxt, ii(len, 1));
    }



    int qs;
    scanf("%d\n", &qs);

    int t = 0;
    for (int q = 0; q < qs; q++) {
        ++t;

        char op;
        scanf("%c ", &op);

        if (op == 'P') {

            int x, y;
            scanf("%d %d\n", &x, &y);
            //printf("P %d %d\n", x, y);

            x--, y--;

            ii a = h1.query(x, y),
               b = h2.query(x, y);

            printf("%d\n", min(a.first + t * a.second, b.first + t * b.second));

        } else if (op == 'R') {

            int no, val;
            scanf("%d %d\n", &no, &val);
            //printf("R %d %d\n", no, val);
            no--;

            int cur = edges[no].first.first,
                nxt = edges[no].first.second;

            //printf("%d %d\n", cur, nxt);

            if (used[no]) {
                //printf("A\n");
                h1.update_cost(cur, nxt, ii(val - t, 1));
            }

            if (used2[no]) {
                //printf("B\n");
                h2.update_cost(cur, nxt, ii(val - t, 1));
            }

        } else {
            assert(false);
        }
    }


    return 0;
}
